# combines inspect_data_updated.py and functions from old extract_FT_PO.py
from __future__ import print_function
import os
import numpy as np
import csv 

def csv_skel(file_path):
    # csv skeleton
    # read csv file generated by our data collection system:
    # first line is the start time, following lines are the data

    # returns a tuple: (starttime, num_row, num_col, the data)

    # read start_time
    f = open(file_path, mode='r')
    reader = csv.reader(f, delimiter=',')
    meta = []
    skip_header = 0
    for i, row in enumerate(reader):
        if len(row) == 1:
            meta.append(int(row[0]))
            skip_header += 1
        else:
            break
    f.close()

    # read data
    data = np.genfromtxt(file_path, delimiter=',', skip_header=skip_header)

    return (meta, data.shape[0], data.shape[1], data)

def extract_FT_from_file(file_path_abs):
    meta, _, _, data_with_time = csv_skel(file_path_abs)
    assert len(meta) == 1
    start_time = meta[0]
    time_stamps = np.array(data_with_time[:, 0], dtype=np.int32)
    data = data_with_time[:, 1:]
    return start_time, time_stamps, data

def extract_PO_from_file_optitrack(file_path_abs):
    # extract valid trackable data, i.e., not all -1
    # returns a list in which valid trackable is a numpy array, otherwise None

    meta, _, ncol, data_with_time = csv_skel(file_path_abs)
    time_stamps = np.array(data_with_time[:, 0], dtype=np.int32)
    PO_data = [None, None]
    assert len(meta) == 2
    start_time = meta[0]
    num_trackable = meta[1]
    for i in range(num_trackable):
        data_trackable = data_with_time[:, 1 + 8 * i: 1 + 8 * (i + 1)]
        data_mean = np.mean(data_trackable)
        assert np.allclose(data_trackable[:, 0], i+1)
        # see whether the value is the designated "-1"
        if not np.allclose(data_mean, -1):
            PO_data[i] = data_trackable # insert into position, not appending

    return start_time, time_stamps, PO_data

def extract_PO_from_file_patriot(file_path_abs):
    # extract one or two patriot
    meta, _, ncol, data_with_time = csv_skel(file_path_abs)
    PO_data = [None, None]
    start_time = meta[0]
    time_stamps = np.array(data_with_time[:, 0], dtype=np.int32)
    ncol_correct = ncol == 7 or ncol == 8 or ncol == 15
    assert ncol_correct, 'ncol={} is not seen'.format(ncol)
    if ncol == 7:
        PO_data[0] = data_with_time[:, 1:]
    elif ncol == 8:
        PO_data[0] = data_with_time[:, 2:]
    elif ncol == 15:
        PO_data[0] = data_with_time[:, 2:8]
        PO_data[1] = data_with_time[:, 9:15]

    return start_time, time_stamps, PO_data



def extract_FT_PO_from_trial(trial_path_abs):
    # extract the FT data from a trial folder
    files = os.listdir(trial_path_abs)

    # each value is a tuple (start_time, time_stamps, data)
    data_dict = {}
    for f in files:
        file_path_abs = os.path.join(trial_path_abs, f)
        if f.endswith('mini40.csv'):
            data_dict['mini40'] = extract_FT_from_file(file_path_abs)

        if f.endswith('mocap.csv'):
            data_dict['optitrack'] = extract_PO_from_file_optitrack(file_path_abs)

        if f.endswith('patriot.csv'):
            data_dict['patriot'] = extract_PO_from_file_patriot(file_path_abs)

    # assert that the start time's are equal
    start_times = set([x[0] for x in data_dict.values()])
    assert len(start_times) == 1, 'start times are different: {}'.format(start_times)

    return data_dict
