

function [data_matrix, num_frames, num_trackables] = ReadOptitrackData(file_name)
% read .csv file exported by Optitrack motion capture software "Tracking Tool".
%
% input:  file_name is a string
% output: data_matrix is a N*C matrix that includes all the data in the row
%         labeled "frame". N is the number of frames. 
%         C is the number of columns, varies depending on how many trackables
%         there are. 
%         num_frames;
%         num_trackables;
%
% For description of each column, consult the header of the data file.
% 
% author: Yongqiang Huang
% last modified: 11/27/2014.

file_id = fopen(file_name);
num_rows_info = 2; % only read frame count and trackable count
row_offset = 41;   % determined by looking at file
data_cell = textscan(file_id, '%s %s %d', num_rows_info, 'Delimiter', ',',...
    'HeaderLines', 41, 'CollectOutput', false);

num_frames = data_cell{1, 3}(1);
num_trackables = data_cell{1, 3}(2);


num_columns_per_trackable = 11; % file format
% first column is time stamp, second column is trackable count, those are
% the '1'. The rest is specific trackable information.
% each time read one row.
%num_columns = 2 + num_trackables * num_columns_per_trackable;

row_offset = row_offset + num_rows_info + num_trackables;

% the column 'frame'
format_specs = '%s';
num_numerical_columns = 3 + num_trackables*num_columns_per_trackable; 
% determined by looking at the file

for i = 1: num_numerical_columns
    format_specs = strcat(format_specs, '%f');
end

frewind(file_id);
data_matrix = zeros(num_frames, num_numerical_columns);

for i = 1:num_frames
    data_cell = textscan(file_id, format_specs, 1, 'Delimiter', ',', ...
        'HeaderLines', row_offset, 'CollectOutput', true);
    data_matrix(i, :) = data_cell{1, 2};
    row_offset = 1 + num_trackables;
end

fclose(file_id);

end % end of function






















