function traj = TT26dof(mocap_data_name)
% for IROS2016
% convert tracking tool data to 6 DOF trajectory, each column is
% [x; y; z; phi; theta; psi]
% derived from plot_from_data_collection.m
%
% reference: "Computing Euler Angles from a Rotation Matrix, Greg Slabaugh, August 20, 1999."
% phi:   about z
% theta: about y
% psi:   about x
% R = Rz * Ry * Rx
% phi, theta, psi are in radians

% NOTE: 
% Assumes ONLY ONE trackable in the data !!! Reflected in Line 40 and 41.

[matrix3D, nframe, ~, ~] = readTTData(mocap_data_name);

pos3D  = matrix3D(:, 1:3, :); % position   [x, y, z]
quat3D = matrix3D(:, 4:7, :); % quaternion [qw, qx, qy, qz]
 
% convert from the API's left-handed system to our right-handed system

% flip the z position value
pos3D(:, 3, :) = -pos3D(:, 3, :);

% flip the z-value of the rotation axis of the quaternion
quat3D(:, 4, :) = -quat3D(:, 4, :);


% alternate euler angle solutions from rotation matrix
euler_traj_1 = zeros(3, nframe);
euler_traj_2 = zeros(3, nframe);

pos_traj = zeros(3, nframe);

for f = 1:nframe
    
    % construct transformation matrix in frame 1: A1
    % ASSUMES ONLY ONE TRACKABLE !!!
    R = quaternionRotationMatrix(quat3D(f, :, 1)); % rotation
    t = pos3D(f, :, 1)';  
    
    A1 = [R             t;
          zeros(1, 3)   1];
    
    % convert from frame 1 to frame 0  
    A0 = convertFrame1to0(A1);
    
    pos_traj(:, f) = A0(1:3, 4);
    
    R0 = A0(1:3, 1:3);   
    
    [sol_1, sol_2] = rotm2euler(R0);
    euler_traj_1(:, f) = sol_1;
    euler_traj_2(:, f) = sol_2;
        
end

% compute energy of two euler trajectories
energy_1 = norm(euler_traj_1, 'fro');
energy_2 = norm(euler_traj_2, 'fro');

if energy_1 < energy_2
    euler_traj = euler_traj_1;
else
    euler_traj = euler_traj_2;
end

traj = [pos_traj; euler_traj];


end % end if TT26dof