% branched from plot_from_data_collection.m
% 
% for IROS 2016 video 
%
% 03/25/2016

clear; clc; close all hidden;


%% USER INPUT

% choose from [0, 1, 2, 3, 4, 5]
motion_code = 5

% choose from [0, 19]
trial_index = 0

%% process motion_code and trial_index

if motion_code == 4
    subject_str = 'jeanine';
else
    subject_str = 'roger';
end

subject_str = strcat('s', subject_str);
motion_str = strcat('m', num2str(motion_code));
trial_str = strcat('t', num2str(trial_index));

data_path = '..\data_raw\';
data_path = strcat(data_path, subject_str, '\', motion_str, '\', trial_str, '\');
file_name = strcat(subject_str, '-', motion_str, '-', trial_str, '-mocap.csv');

%% add data path

addpath(data_path);


%% obtain raw data

% input exported .csv file name ---- 
[matrix3D, nframe, ntrackable, trackableID] = readTTData(file_name);

pos3D  = matrix3D(:, 1:3, :); % position   [x, y, z]
quat3D = matrix3D(:, 4:7, :); % quaternion [qw, qx, qy, qz]
 

%% convert from the API's left-handed system to our right-handed system

% flip the z position value
pos3D(:, 3, :) = -pos3D(:, 3, :);

% flip the z-value of the rotation axis of the quaternion
quat3D(:, 4, :) = -quat3D(:, 4, :);

%% (temporary) plot position and quaternion

figure;
subplot(3, 1, 1); plot(pos3D(:, 1));
subplot(3, 1, 2); plot(pos3D(:, 2));
subplot(3, 1, 3); plot(pos3D(:, 3));


for i = 1:ntrackable
    
    figure;
    subplot(4, 1, 1); plot(quat3D(:, 1, i)); hold on;
    subplot(4, 1, 2); plot(quat3D(:, 2, i)); hold on;
    subplot(4, 1, 3); plot(quat3D(:, 3, i)); hold on;
    subplot(4, 1, 4); plot(quat3D(:, 4, i)); hold on;

end


%% initialize figure. Plot first point of each trackable

figure;
hold on;
grid on;
axis equal;
xlabel('x');
ylabel('y');
zlabel('z');

hpos =   cell(1, ntrackable);
harrow = cell(3, ntrackable);
htext =  cell(3, ntrackable);

xbasis = 0.5 * [1 0 0]';
ybasis = 0.5 * [0 1 0]';
zbasis = 0.5 * [0 0 1]';


for i = 1:ntrackable
    
    % construct transformation matrix in frame 1: A1
    R = quaternionRotationMatrix(quat3D(1, :, i)); % rotation
    t = pos3D(1, :, i)';                           % translation

    A1 = [R             t;
          zeros(1, 3)   1];

    
    % convert from frame 1 to frame 0  
    A0 = convertFrame1to0(A1);
    

    x = A0(1, 4);
    y = A0(2, 4);
    z = A0(3, 4);
    

    hpos{i} = plot3(x, y, z);
    hpos{i}.Marker = '.';
    hpos{i}.LineStyle = 'none';
    
    xbasisNew = A0(1:3, 1:3) * xbasis;
    ybasisNew = A0(1:3, 1:3) * ybasis;
    zbasisNew = A0(1:3, 1:3) * zbasis;
    
    harrow{1, i} = quiver3(x, y, z, xbasisNew(1), xbasisNew(2), xbasisNew(3));
    harrow{1, i}.Color = 'r';
    harrow{2, i} = quiver3(x, y, z, ybasisNew(1), ybasisNew(2), ybasisNew(3));
    harrow{2, i}.Color = 'g';
    harrow{3, i} = quiver3(x, y, z, zbasisNew(1), zbasisNew(2), zbasisNew(3));
    harrow{3, i}.Color = 'b';
    
    xArrowTerminal = [x; y; z] + xbasisNew;
    yArrowTerminal = [x; y; z] + ybasisNew;
    zArrowTerminal = [x; y; z] + zbasisNew;
    
    htext{1, i} = text(xArrowTerminal(1), xArrowTerminal(2), xArrowTerminal(3), 'x');
    htext{2, i} = text(yArrowTerminal(1), yArrowTerminal(2), yArrowTerminal(3), 'y');
    htext{3, i} = text(zArrowTerminal(1), zArrowTerminal(2), zArrowTerminal(3), 'z');
    
    
    
end % for i = 1:ntrackable

%% update figure

for f = 1:nframe
    
    fprintf('%2.0f%%\n', f/nframe*100);
    

    
    for i = 1:ntrackable
        
        % construct transformation matrix in frame 1: A1
        R = quaternionRotationMatrix(quat3D(f, :, i)); % rotation
        t = pos3D(f, :, i)';                           % translation
        
        A1 = [R             t;
              zeros(1, 3)   1];       
         
        % convert from frame 1 to frame 0  
        A0 = convertFrame1to0(A1);
       
  
        x = A0(1, 4);
        y = A0(2, 4);
        z = A0(3, 4);
        
        hpos{i}.XData = [hpos{i}.XData x];
        hpos{i}.YData = [hpos{i}.YData y];
        hpos{i}.ZData = [hpos{i}.ZData z];
        
        
        xbasisNew = A0(1:3, 1:3) * xbasis;
        ybasisNew = A0(1:3, 1:3) * ybasis;
        zbasisNew = A0(1:3, 1:3) * zbasis;
        
        harrow{1, i}.XData = x;
        harrow{1, i}.YData = y;
        harrow{1, i}.ZData = z;
        harrow{1, i}.UData = xbasisNew(1);
        harrow{1, i}.VData = xbasisNew(2);
        harrow{1, i}.WData = xbasisNew(3);
        
        harrow{2, i}.XData = x;
        harrow{2, i}.YData = y;
        harrow{2, i}.ZData = z;
        harrow{2, i}.UData = ybasisNew(1);
        harrow{2, i}.VData = ybasisNew(2);
        harrow{2, i}.WData = ybasisNew(3);
        
        harrow{3, i}.XData = x;
        harrow{3, i}.YData = y;
        harrow{3, i}.ZData = z;
        harrow{3, i}.UData = zbasisNew(1);
        harrow{3, i}.VData = zbasisNew(2);
        harrow{3, i}.WData = zbasisNew(3);
        
        xArrowTerminal = [x; y; z] + xbasisNew;
        yArrowTerminal = [x; y; z] + ybasisNew;
        zArrowTerminal = [x; y; z] + zbasisNew;
    
        htext{1, i}.Position = xArrowTerminal;
        htext{2, i}.Position = yArrowTerminal;
        htext{3, i}.Position = zArrowTerminal;
               
        
    end % for i = 1:ntrackable
    
    drawnow;
    %pause(0.01);
    
    
end % for f = 1:nframe

