function axesdata = initialize_axes(axes_handle, axesdata)
% plotting the first frame of the imported trackingtool data
% axes contents include position and orientation of all trackables. 
% 
% axes_data is a struct of data needed for plotting
% Yongqiang Huang
% 04/31/2016

% figure;
cla(axes_handle); % clear axis 
hold(axes_handle, 'on');
grid(axes_handle, 'on');
axis(axes_handle, 'equal');
xlabel(axes_handle, 'x');
ylabel(axes_handle, 'y');
zlabel(axes_handle, 'z');



for i = 1:axesdata.ntrackable
    
    % construct transformation matrix in frame 1: A1
    R = quaternionRotationMatrix(axesdata.quat3D(1, :, i)); % rotation
    t = axesdata.pos3D(1, :, i)';                           % translation

    A1 = [R             t;
          zeros(1, 3)   1];

    
    % convert from frame 1 to frame 0  
    A0 = convertFrame1to0(A1);
    

    x = A0(1, 4);
    y = A0(2, 4);
    z = A0(3, 4);
    

    axesdata.hpos_axes{i}           = plot3(axes_handle, x, y, z);
    axesdata.hpos_axes{i}.Marker    = '.';
    axesdata.hpos_axes{i}.LineStyle = 'none';
    
    xbasisNew = A0(1:3, 1:3) * axesdata.xbasis;
    ybasisNew = A0(1:3, 1:3) * axesdata.ybasis;
    zbasisNew = A0(1:3, 1:3) * axesdata.zbasis;
    
    axesdata.harrow_axes{1, i}       = quiver3(axes_handle, x, y, z, xbasisNew(1), xbasisNew(2), xbasisNew(3));
    axesdata.harrow_axes{1, i}.Color = 'r';
    axesdata.harrow_axes{2, i}       = quiver3(axes_handle, x, y, z, ybasisNew(1), ybasisNew(2), ybasisNew(3));
    axesdata.harrow_axes{2, i}.Color = 'g';
    axesdata.harrow_axes{3, i}       = quiver3(axes_handle, x, y, z, zbasisNew(1), zbasisNew(2), zbasisNew(3));
    axesdata.harrow_axes{3, i}.Color = 'b';
    
    xArrowTerminal = [x; y; z] + xbasisNew;
    yArrowTerminal = [x; y; z] + ybasisNew;
    zArrowTerminal = [x; y; z] + zbasisNew;
    
    axesdata.htext_axes{1, i} = text(xArrowTerminal(1), xArrowTerminal(2), xArrowTerminal(3), 'x');
    axesdata.htext_axes{2, i} = text(yArrowTerminal(1), yArrowTerminal(2), yArrowTerminal(3), 'y');
    axesdata.htext_axes{3, i} = text(zArrowTerminal(1), zArrowTerminal(2), zArrowTerminal(3), 'z');
    
         
end % for i = 1:ntrackable


end