function axesdata = load_datafile_airplane(filename)
% derived from load_datafile()
% initializes data for drawing airplanes
%
% Yongqiang Huang
% 05/03/2016


% input exported .csv file name ---- 
[matrix3D, nframe, ntrackable, trackableID] = readTTData(filename);

pos3D  = matrix3D(:, 1:3, :); % position   [x, y, z]
quat3D = matrix3D(:, 4:7, :); % quaternion [qw, qx, qy, qz] 

% convert from the API's left-handed system to our right-handed system
% flip the z position value
pos3D(:, 3, :) = -pos3D(:, 3, :);
% flip the z-value of the rotation axis of the quaternion
quat3D(:, 4, :) = -quat3D(:, 4, :);


% package struct
%axesdata.pos3D       = pos3D;
%axesdata.quat3D      = quat3D;
axesdata.nframe      = nframe;
axesdata.ntrackable  = ntrackable;
axesdata.trackableID = trackableID;
axesdata.A0          = cell(1, ntrackable); % includes all 6dof data
axesdata.pos         = cell(1, ntrackable); % all position of trackable

axesdata.airplane    = cell(1, ntrackable);
axesdata.hpatch_axes = cell(1, ntrackable);

% compute all the A0 matrices, and pos matrices
for i = 1:axesdata.ntrackable
    
    axesdata.A0{i} = cell(1, axesdata.nframe);
    axesdata.pos{i} = zeros(3, axesdata.nframe);
    
    for f = 1:axesdata.nframe
        % construct transformation matrix in frame 1: A1
        R = quaternionRotationMatrix(quat3D(f, :, i)); % rotation
        t = pos3D(f, :, i)';                           % translation

        A1 = [R             t;
              zeros(1, 3)   1];


        % convert from frame 1 to frame 0  
        axesdata.A0{i}{f} = convertFrame1to0(A1);
        
        % save position specifically
        axesdata.pos{i}(:, f) = axesdata.A0{i}{f}(1:3, 4);
        
    end
    
end

% compute the airplane patch
for i = 1:axesdata.ntrackable
    axesdata.airplane{i} = export_airplane();
end




end