function R = quaternionRotationMatrix(quaternion)

% compute the rotation matrix corresponding to a quaternion
% 
% INPUT: quaternion: a 4-vector unit quaternion in form [qw, qx, qy, qz]
% OUTPUT: R: a 3*3 rotation matrix

q0 = quaternion(1);
q1 = quaternion(2);
q2 = quaternion(3);
q3 = quaternion(4);


Rq11 = 2*(q0^2 + q1^2) - 1;
Rq12 = 2*(q1*q2 - q0*q3);
Rq13 = 2*(q1*q3 + q0*q2);

Rq21 = 2*(q1*q2 + q0*q3);
Rq22 = 2*(q0^2 + q2^2) - 1;
Rq23 = 2*(q2*q3 - q0*q1);

Rq31 = 2*(q1*q3 - q0*q2);
Rq32 = 2*(q2*q3 + q0*q1);
Rq33 = 2*(q0^2 + q3^2) - 1;

R = [Rq11 Rq12 Rq13;
      Rq21 Rq22 Rq23;
      Rq31 Rq32 Rq33];
  


end