function [matrix3D, nframe, ntrackable, trackableID] = readTTData(dataName)
% [matrix3D, nframe, ntrackable] = readTTData(dataName)
% extracts potision and quaternion of each trackable from data collected
% by our system. 
%
% It needs to be kept consistent with the output format of OUR data
% collection system.
% 
% INPUT: name of the data file output by OUR data collection system
% OUTPUT:
%       matrix3D: a 3-dimensional matrix of position and quaternion of 
%                 each trackable. First dimension is the frame, Second
%                 dimension is the position and quaternion, and Third 
%                 dimension is the trackable.
%       nframe: number of frames.
%       ntrackable: number of trackables.
%       trackableID: ID of trackable, should be integer
%
% Yongqiang Huang
% 11/13/2015

M = csvread(dataName);

ntrackable = M(2, 1);

trackableID = zeros(1, ntrackable);

rowDataStart = 3; % the row where data starts

for i = 1:ntrackable
    trackableID(i) = M(rowDataStart, 1 + (i-1)*8 + 1);
end

nframe = size(M, 1) - 2;

% 7 columns: x, y, z, qw, qx, qy, qz, yaw, pitch, roll
matrix3D = zeros(nframe, 7, ntrackable);

for i = 1:ntrackable
    matrix3D(:, :, i) = M(3:end, (i-1)*8+3 : i*8+1);
end





end