function [A0cell, pos, nframe] = read_patriot_data(filename)
% read patriot data generated by the data collection system
% assumes only one trackable (because there is only one tracker right now)
% 
% NOTE: The transformation of position and orientation works ONLY on: 
%       "Garfield_June3, 
%        Garfield_June_5,
%        Garfield_June_21"
%
% 06/22/2016

M = csvread(filename);

nframe = size(M, 1) - 1;

pos = M(2:end, 2:4)' / 100; % convert from centimeter to meter
ori = M(2:end, 5:7)' * pi / 180; % convert from degree to radiance

% convert patriot frame (frame 2) to gui visualization frame (frame 0)
% assumes patriot hemisphere tracking is not enabled, and tracking occurs
% in +x hemisphere.

% makes a copy
pos2 = pos;
% x0 = -y2
pos(1, :) = -pos2(2, :);
% y0 = -x2
pos(2, :) = -pos2(1, :);
% z0 = z2, no action required

 
A0cell = cell(1, nframe);

% figure;
% subplot(3, 2, 1); plot(pos(1, :)); ylabel('x'); axis tight;
% subplot(3, 2, 3); plot(pos(2, :)); ylabel('y'); axis tight;
% subplot(3, 2, 5); plot(pos(3, :)); ylabel('z'); axis tight;
% subplot(3, 2, 2); plot(ori(1, :)); ylabel('yaw');   axis tight;
% subplot(3, 2, 4); plot(ori(2, :)); ylabel('pitch'); axis tight;
% subplot(3, 2, 6); plot(ori(3, :)); ylabel('roll');  axis tight;


for f = 1:nframe
    R2 = euler2rotm(ori(:, f)); % rotation matrix in patriot frame
    t = pos(:, f);
    
    R0 = patriot_frame2_to_0(R2);
    
    A2 = [R0            t;
          zeros(1, 3)   1];
      
    A0cell{f} = A2;
    
end





