function [A0_all_trackable, pos_all_trackable, nframe, ntrackable, trackableID] ...
    = read_patriot_data_hemis_twosensor(filename)
% derived from read_patriot_data_hemis()
% read patriot data file with up to two sensors.
% the file may have one OR two sensor data. This code should be able to 
% process both.
%
% 07/11/2016

M = csvread(filename);

% determine number of trackables (actually, number of sensors)
ncol = size(M, 2);
if ncol == 15
    ntrackable = 2;
elseif (ncol == 8 || ncol == 7)
    ntrackable = 1;
else
    error('number of columns of patriot data file is neither 8 nor 15.');
end

% get trackable ID
trackableID = zeros(1, ntrackable);
for i = 0:ntrackable-1
    trackableID(i+1) = M(2, 2 + i*7);
end

nframe = size(M, 1) - 1;

A0_all_trackable  = cell(1, ntrackable); % includes all 6dof data
pos_all_trackable = cell(1, ntrackable); % all position of trackable

for i = 0:ntrackable-1
    
    % get position and orientation 
    pos = M(2:end, (3 + i*7):(5 + i*7))' / 100; % convert from centimeter to meter
    ori = M(2:end, (6 + i*7):(8 + i*7))' * pi / 180; % convert from degree to radiance
    
    A0_all_trackable{i+1} = cell(1, nframe);
    pos_all_trackable{i+1} = zeros(3, nframe);
    
    for f = 1:nframe
        R = euler2rotm(ori(:, f)); % rotation matrix in patriot frame
        t = pos(:, f);

        %R0 = patriot_frame2_to_0(R2);

        A2 = [R            t;
              zeros(1, 3)   1];
         
        % added 03/04/2018, transform from the PO sensor to the base
        % of tool for the first PO sensor
        d = [0.143; 0; 0.007]; % unit meter
        T2tool = [eye(3),     d;
                  zeros(1, 3), 1];
        if i == 0
            A2 = A2 * T2tool;
        end

        A0 = patriot_frame2_to_0_transfm(A2);

        A0_all_trackable{i+1}{f} = A0;
        pos_all_trackable{i+1}(:, f) = A0(1:3, 4);

    end
end










