function axesdata = update_axes(axesdata, current_frame)
% update figure when one of the related GUI objects are interacted with

ntrackable  = axesdata.ntrackable;
quat3D      = axesdata.quat3D;
pos3D       = axesdata.pos3D;
hpos_axes   = axesdata.hpos_axes;
harrow_axes = axesdata.harrow_axes;
htext_axes  = axesdata.htext_axes;
xbasis      = axesdata.xbasis;
ybasis      = axesdata.ybasis;
zbasis      = axesdata.zbasis;

% initialize while loop
f = current_frame;
    
for i = 1:ntrackable

    % construct transformation matrix in frame 1: A1
    R = quaternionRotationMatrix(quat3D(f, :, i)); % rotation
    t = pos3D(f, :, i)';                           % translation

    A1 = [R             t;
          zeros(1, 3)   1];       

    % convert from frame 1 to frame 0  
    A0 = convertFrame1to0(A1);


    x = A0(1, 4);
    y = A0(2, 4);
    z = A0(3, 4);

    hpos_axes{i}.XData = [hpos_axes{i}.XData x];
    hpos_axes{i}.YData = [hpos_axes{i}.YData y];
    hpos_axes{i}.ZData = [hpos_axes{i}.ZData z];
            

    xbasisNew = A0(1:3, 1:3) * xbasis;
    ybasisNew = A0(1:3, 1:3) * ybasis;
    zbasisNew = A0(1:3, 1:3) * zbasis;

    harrow_axes{1, i}.XData = x;
    harrow_axes{1, i}.YData = y;
    harrow_axes{1, i}.ZData = z;
    harrow_axes{1, i}.UData = xbasisNew(1);
    harrow_axes{1, i}.VData = xbasisNew(2);
    harrow_axes{1, i}.WData = xbasisNew(3);

    harrow_axes{2, i}.XData = x;
    harrow_axes{2, i}.YData = y;
    harrow_axes{2, i}.ZData = z;
    harrow_axes{2, i}.UData = ybasisNew(1);
    harrow_axes{2, i}.VData = ybasisNew(2);
    harrow_axes{2, i}.WData = ybasisNew(3);

    harrow_axes{3, i}.XData = x;
    harrow_axes{3, i}.YData = y;
    harrow_axes{3, i}.ZData = z;
    harrow_axes{3, i}.UData = zbasisNew(1);
    harrow_axes{3, i}.VData = zbasisNew(2);
    harrow_axes{3, i}.WData = zbasisNew(3);

    xArrowTerminal = [x; y; z] + xbasisNew;
    yArrowTerminal = [x; y; z] + ybasisNew;
    zArrowTerminal = [x; y; z] + zbasisNew;

    htext_axes{1, i}.Position = xArrowTerminal;
    htext_axes{2, i}.Position = yArrowTerminal;
    htext_axes{3, i}.Position = zArrowTerminal;


end % for i = 1:ntrackable

drawnow;
   

% package splot
axesdata.quat3D      = quat3D;
axesdata.pos3D       = pos3D;
axesdata.hpos_axes   = hpos_axes;
axesdata.harrow_axes = harrow_axes;
axesdata.htext_axes  = htext_axes;
axesdata.xbasis      = xbasis;
axesdata.ybasis      = ybasis;
axesdata.zbasis      = zbasis;



