function hfigure = visualizer_v1_1_patriot_twosensor(varargin)
% derived from visualizer_v1_1_patriot()
% parses up to two patriot sensors
%
% 07/11/2016

% can open file from anywhere
% 06/11/2017

clear;
clc;
close all hidden;

% add draw_plane to path
current_path = pwd;
draw_plane_path = [current_path, '/draw_airplane/'];
addpath(draw_plane_path);

%% layout UI
hfigure         = figure(...
                'Visible', 'off', ...
                'Name', 'Visualizer', ...
                'Position', [1, 1, 1046, 567]);

hedit           = uicontrol(hfigure, ...
                'Style', 'edit', ...
                'String', '', ...
                'Position', [890, 24, 60, 34], ...
                'Callback', @edit_frame);

hpush_play      = uicontrol(hfigure,...
                'Style', 'pushbutton',...
                'String', 'Play',...
                'Position', [964, 300, 60, 40], ...
                'Callback', @play_animation);

hpush_pause     = uicontrol(hfigure, ...
                'Style', 'pushbutton', ...
                'String', 'Pause', ...
                'Position', [861, 300, 60, 40], ...
                'Callback', @pause_animation);

hpush_choose    = uicontrol(hfigure, ...
                'Style', 'pushbutton', ...
                'String', 'Choose file', ...
                'Position', [884, 478, 100, 40], ...
                'Callback', @choose_file);

hslider         = uicontrol(hfigure, ...
                'Style', 'slider', ...
                'Position', [90, 26, 768, 30], ...
                'Callback', @slider_release_mouse);

htext_nframe    = uicontrol(hfigure, ...
                'Style', 'text', ...
                'String', '', ...
                'Position', [858, 214, 130, 30]);
            
htext_toggle    = uicontrol(hfigure, ...
                'Style', 'text', ...
                'String', 'Coordinate frames represented by:', ...
                'Position', [864, 407, 150, 40]);

htext_cframe  = uicontrol(hfigure, ...
                'Style', 'text', ...
                'String', 'Current frame:', ...
                'Position', [891, 63, 60, 34]);
            
haxes           = axes('Parent', hfigure, ...
                'Position', [0.085, 0.269, 0.7, 0.7]);

htoggle         = uicontrol(hfigure, ...
                'Style', 'togglebutton', ...
                'Value', 1, ...
                'String', 'Airplane', ...
                'Position', [888, 367, 100, 40], ...
                'Callback', @toggle);
            
hpush_clear     = uicontrol(hfigure, ...
                'Style', 'pushbutton', ...
                'String', 'Clear Data', ...
                'Position', [928, 162, 100, 40], ...
                'Callback', @clear_data);


hfigure.Units       = 'normalized';
hedit.Units         = 'normalized';
hpush_play.Units    = 'normalized';
hpush_pause.Units   = 'normalized';
hpush_choose.Units  = 'normalized';
hslider.Units       = 'normalized';
htext_nframe.Units  = 'normalized';
htext_cframe.Units  = 'normalized';
htext_toggle.Units  = 'normalized';
haxes.Units         = 'normalized';
htoggle.Units       = 'normalized';
hpush_clear         = 'normalized';

hfigure.Visible = 'on';



%% declare shared variable
gcurrent_frame = 1;

% flag of whether can play animation
gplay = true;

% structure for plotting
gplot = struct();

% flag of whether draw airplane to represent coordinate frame
gdraw_airplane = true;


%% Define Callback functions

function edit_frame(hObject, callbackdata)
% callback for hedit 

    f_exact = str2double(hObject.String);
    f_int = round(f_exact);
    % Determine whether val is a number between 1 and nframe.
    if isnumeric(f_int) && length(f_int)==1 && ...
       f_int >= hslider.Min && ...
       f_int <= hslider.Max
        hslider.Value = f_int;

        gcurrent_frame = f_int;
        if gdraw_airplane == true
            gplot = update_axes_airplane(gplot, gcurrent_frame);
        else
            gplot = update_axes_arrow(gplot, gcurrent_frame);
        end
    else
       string2display = ['current frame should be between ', ...
                        num2str(hslider.Min),...
                        ' and ',...
                        num2str(hslider.Max),...
                        '!'];
       % Restore focus to the edit text box after error
       msgbox(string2display);

    end    
end

function choose_file(hObject, callbackdata)
% callback for hpush_choose

    [fileName, pathName] = uigetfile('*.csv');
    filename = fullfile(pathName, fileName);
   
    % determine if one or two sensors
    M = csvread(filename);
    ncol = size(M, 2);
    
    if gdraw_airplane == true
        if (ncol == 15 || ncol == 8)
            gplot = load_patriotfile_airplane_twosensor(filename);
        elseif ncol == 7
            gplot = load_patriotfile_airplane(filename);
        end
        gplot = initialize_axes_airplane(haxes, gplot);
    else
        gplot = load_datafile_arrow(filename);
        gplot = initialize_axes_arrow(haxes, gplot);
    end

    gcurrent_frame = 1;

    % initialize other UI objects
    htext_nframe.String    = ['nframe: ', num2str(gplot.nframe)];
    hslider.Min     = 1;
    hslider.Max     = gplot.nframe;
    hslider.Value   = gcurrent_frame;
    hedit.String    = num2str(gcurrent_frame);
end % choose_file

function play_animation(hObject, callbackdata)
% callback for hpush_play 

    % enable playing
    gplay = true;

    % initialize while loop
    f = gcurrent_frame;
    play = gplay;
    nframe = gplot.nframe;

    while (play && f <= nframe)

        fprintf('%2.0f%%, handles.play=%d\n', f/nframe*100, play);

        if gdraw_airplane == true
            gplot = update_axes_airplane(gplot, gcurrent_frame);
        else
            gplot = update_axes_arrow(gplot, gcurrent_frame);
        end

        % update axes_userdata
        gcurrent_frame = f;

        % update edittext string
        hedit.String = num2str(f);
        hslider.Value = f;

        f = f + 1;

        % determine if continue playing
        play = gplay;

    end % while loop


end % play_animation

function pause_animation(hObject, callbackdata)
% callback of hpush_pause

    if gplay == true
        gplay = false;
        fprintf('animation paused.\n');
    end
end

function slider_release_mouse(hObject, callbackdata)
% callback to hslider, after  the mouse has been released 

    f_exact = hObject.Value;
    f_int = round(f_exact);
    hedit.String = num2str(f_int);
    hObject.Value = f_int;

    gcurrent_frame = f_int;

    if gdraw_airplane == true
        gplot = update_axes_airplane(gplot, gcurrent_frame);
    else
        gplot = update_axes_arrow(gplot, gcurrent_frame);
    end
end

% listen to slider value change
addlistener(hslider, 'Value', 'PostSet', @(hObject, event) slider_drag_mouse);

function slider_drag_mouse()
% behavior when the slider is being dragged

    f = round(hslider.Value);
    gcurrent_frame = f;
    hedit.String = num2str(f);
    if gdraw_airplane == true
        gplot = update_axes_airplane(gplot, gcurrent_frame);
    else
        gplot = update_axes_arrow(gplot, gcurrent_frame);
    end
end

function toggle(hObject, callbackdata)
% callback for htoggle
    if hObject.Value == hObject.Min
        gdraw_airplane = false;
        hObject.String = 'Arrow';

        % update the axes
        % only when data have been loaded
        if (~isempty(fieldnames(gplot)))
            gplot = modify_axesdata(gplot, 'airplane2arrow');
            gplot = initialize_axes_arrow(haxes, gplot);
            gplot = update_axes_arrow(gplot, gcurrent_frame);
        end

    elseif hObject.Value == hObject.Max
        gdraw_airplane = true;
        hObject.String = 'Airplane';

        % update the axes when data have been loaded
        if (~isempty(fieldnames(gplot)))
            gplot = modify_axesdata(gplot, 'arrow2airplane');
            gplot = initialize_axes_airplane(haxes, gplot);
            gplot = update_axes_airplane(gplot, gcurrent_frame);
        end

    end

end

function clear_data(hObject, callbackdata)
% callback function for hpush_clear
    gplot = struct();
    cla(haxes);
    htext_nframe.String = '';
    hslider.Value = hslider.Min;
    hedit.String = '';
end

















end % function visualizer


































